length.trajectory: Length of the Trajectory

View source: R/trajectory.R

length.trajectoryR Documentation

Length of the Trajectory

Description

Calculates the total length of the trajectory, which is the sum of the distances between consecutive points in the 'Trajectory' object.

Usage

## S3 method for class 'trajectory'
length(x)

Arguments

x

An object of class 'Trajectory'.

Value

A numeric value representing the total length of the trajectory.


BioTrajectory documentation built on Nov. 26, 2025, 5:07 p.m.