normalVectors: Calculate the normals from tangents of a trajectory object

View source: R/normalVectors.R

normalVectorsR Documentation

Calculate the normals from tangents of a trajectory object

Description

This function computes the normal vectors at each point of an object of class 'trajectory' by rotating the tangent vectors 90 degrees.

Usage

normalVectors(obj)

Arguments

obj

An object of class 'trajectory' that contains a component 'points'.

Value

A matrix of the same dimensions as 'obj$points' with the normal vectors. Each row represents a normal vector at a given point, which is obtained by rotating the corresponding tangent vector by 90 degrees.


BioTrajectory documentation built on Nov. 26, 2025, 5:07 p.m.