| or | R Documentation |
Combines two 'Trajectory' objects by concatenating their points. The result is a new trajectory that contains the coordinates of both input trajectories.
## S3 method for class 'trajectory'
tr1 | tr2
tr1 |
A 'Trajectory' object. |
tr2 |
A 'Trajectory' object. |
A new 'Trajectory' object containing the concatenated points of the two input trajectories.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.