plot.trajectory: Plot the Trajectory

View source: R/trajectory.R

plot.trajectoryR Documentation

Plot the Trajectory

Description

Plots the trajectory by displaying the 'x' and 'y' coordinates as points on a 2D plot. Optionally, you can add a line connecting the points.

Usage

## S3 method for class 'trajectory'
plot(x, ..., stepSize = 0)

Arguments

x

A 'Trajectory' object to plot.

...

Other parameters to be passed.

stepSize

An integer specifying the interval for plotting segments of the trajectory. If set to 0, the entire trajectory is plotted. Default is 0.

Value

A plot displaying the trajectory.


BioTrajectory documentation built on Nov. 26, 2025, 5:07 p.m.