summary.trajectory: Summary of the Trajectory

View source: R/trajectory.R

summary.trajectoryR Documentation

Summary of the Trajectory

Description

Generates a summary of the trajectory, including the minimum, maximum, and mean of the 'x' and 'y' coordinates, as well as the total number of frames.

Usage

## S3 method for class 'trajectory'
summary(object, ...)

Arguments

object

An object of class 'Trajectory'.

...

Other parameters to be passed.

Value

A summary object containing statistics for both the 'x' and 'y' coordinates of the trajectory.


BioTrajectory documentation built on Nov. 26, 2025, 5:07 p.m.