| centroid | R Documentation |
This function calculates the centroid of a set of points contained in an object of class 'trajectory'. The centroid is the average of the coordinates of all the points.
centroid(obj)
obj |
An object of class 'trajectory' that must contain a component named 'points'. |
A numeric vector containing the coordinates of the centroid of the points stored in 'obj$points'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.