View source: R/interpolateTrajectory.R
| interpolateTrajectory | R Documentation |
Given a dataset of points, it interpolates to generate intermediate points between them.
interpolateTrajectory(data, n = 4)
data |
An object of class 'trajectory' containing a collection of points with coordinates. |
n |
An integer indicating the number of intermediate points to generate between each pair of points. Default is 4. |
An object of class 'trayectoria', which contains the 'x' and 'y' coordinates, including both the original points and any interpolated points. The 'trayectoria' object allows users to store, manipulate, and analyze the coordinates of the object across frames. If no object is detected in a frame, the corresponding coordinates will be set to 'NA'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.