| isClosed | R Documentation |
This function checks if the distance between the first and last points in an object of class 'trajectory' is smaller than a specified tolerance 'tol'. The distance is calculated using the Euclidean distance between the two points.
isClosed(obj, tol = 1e-06)
obj |
An object of class 'trajectory' that contains a component 'points'. |
tol |
A numeric value specifying the tolerance. If the distance between the first and last points is smaller than this value, the function returns 'TRUE'. Default is '1e-6'. |
A logical value ('TRUE' or 'FALSE'), indicating whether the distance between the first and last points is smaller than 'tol'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.