| length.trajectory | R Documentation |
Calculates the total length of the trajectory, which is the sum of the distances between consecutive points in the 'Trajectory' object.
## S3 method for class 'trajectory'
length(x)
x |
An object of class 'Trajectory'. |
A numeric value representing the total length of the trajectory.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.