View source: R/normalVectors.R
| normalVectors | R Documentation |
This function computes the normal vectors at each point of an object of class 'trajectory' by rotating the tangent vectors 90 degrees.
normalVectors(obj)
obj |
An object of class 'trajectory' that contains a component 'points'. |
A matrix of the same dimensions as 'obj$points' with the normal vectors. Each row represents a normal vector at a given point, which is obtained by rotating the corresponding tangent vector by 90 degrees.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.