| plot.trajectory | R Documentation |
Plots the trajectory by displaying the 'x' and 'y' coordinates as points on a 2D plot. Optionally, you can add a line connecting the points.
## S3 method for class 'trajectory'
plot(x, ..., stepSize = 0)
x |
A 'Trajectory' object to plot. |
... |
Other parameters to be passed. |
stepSize |
An integer specifying the interval for plotting segments of the trajectory. If set to 0, the entire trajectory is plotted. Default is 0. |
A plot displaying the trajectory.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.