| summary.trajectory | R Documentation |
Generates a summary of the trajectory, including the minimum, maximum, and mean of the 'x' and 'y' coordinates, as well as the total number of frames.
## S3 method for class 'trajectory'
summary(object, ...)
object |
An object of class 'Trajectory'. |
... |
Other parameters to be passed. |
A summary object containing statistics for both the 'x' and 'y' coordinates of the trajectory.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.