View source: R/tangentVectors.R
| tangentVectors | R Documentation |
This function calculates the unit tangent vectors at each point of the trajectory represented by a 'trajectory' object. The tangent vectors are computed by taking the difference between consecutive points and normalizing them to have unit length.
tangentVectors(obj)
obj |
An object of class 'trajectory' that contains a component 'points'. |
A matrix where each row is a unit tangent vector corresponding to each pair of consecutive points in 'obj$points'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.